# IoT Greenhouse Service

Python service class supporting K2 Creative IoT Greenhouse hardware and curriculum.

See www.k2controls.net\iot_gh for additional information on educational hardware and curriculum.
